<?php

namespace Litecms\StairStepSetting\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\StairStepSetting\Http\Requests\StairStepSettingsRequest;
use Litecms\StairStepSetting\Interfaces\StairStepSettingsRepositoryInterface;
use Litecms\StairStepSetting\Models\StairStepSettings;

/**
 * Resource controller class for stair_step_settings.
 */
class StairStepSettingsResourceController extends BaseController
{

    /**
     * Initialize stair_step_settings resource controller.
     *
     * @param type StairStepSettingsRepositoryInterface $stair_step_settings
     *
     * @return null
     */
    public function __construct(StairStepSettingsRepositoryInterface $stair_step_settings)
    {
        parent::__construct();
        $this->repository = $stair_step_settings;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\StairStepSetting\Repositories\Criteria\StairStepSettingsResourceCriteria::class);
    }

    /**
     * Display a list of stair_step_settings.
     *
     * @return Response
     */
    public function index(StairStepSettingsRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\StairStepSetting\Repositories\Presenter\StairStepSettingsPresenter::class)
                ->$function();
        }

        $stair_step_settings = $this->repository->paginate();

        return $this->response->title(trans('stair_step_setting::stair_step_settings.names'))
            ->view('stair_step_setting::stair_step_settings.index', true)
            ->data(compact('stair_step_settings'))
            ->output();
    }

    /**
     * Display stair_step_settings.
     *
     * @param Request $request
     * @param Model   $stair_step_settings
     *
     * @return Response
     */
    public function show(StairStepSettingsRequest $request, StairStepSettings $stair_step_settings)
    {

        if ($stair_step_settings->exists) {
            $view = 'stair_step_setting::stair_step_settings.show';
        } else {
            $view = 'stair_step_setting::stair_step_settings.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('stair_step_setting::stair_step_settings.name'))
            ->data(compact('stair_step_settings'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new stair_step_settings.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(StairStepSettingsRequest $request)
    {

        $stair_step_settings = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('stair_step_setting::stair_step_settings.name')) 
            ->view('stair_step_setting::stair_step_settings.create', true) 
            ->data(compact('stair_step_settings'))
            ->output();
    }

    /**
     * Create new stair_step_settings.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(StairStepSettingsRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $stair_step_settings                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('stair_step_setting::stair_step_settings.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('stair_step_setting/stair_step_settings/' . $stair_step_settings->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/stair_step_setting/stair_step_settings'))
                ->redirect();
        }

    }

    /**
     * Show stair_step_settings for editing.
     *
     * @param Request $request
     * @param Model   $stair_step_settings
     *
     * @return Response
     */
    public function edit(StairStepSettingsRequest $request, StairStepSettings $stair_step_settings)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('stair_step_setting::stair_step_settings.name'))
            ->view('stair_step_setting::stair_step_settings.edit', true)
            ->data(compact('stair_step_settings'))
            ->output();
    }

    /**
     * Update the stair_step_settings.
     *
     * @param Request $request
     * @param Model   $stair_step_settings
     *
     * @return Response
     */
    public function update(StairStepSettingsRequest $request, StairStepSettings $stair_step_settings)
    {
        try {
            $attributes = $request->all();

            $stair_step_settings->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('stair_step_setting::stair_step_settings.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('stair_step_setting/stair_step_settings/' . $stair_step_settings->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('stair_step_setting/stair_step_settings/' . $stair_step_settings->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the stair_step_settings.
     *
     * @param Model   $stair_step_settings
     *
     * @return Response
     */
    public function destroy(StairStepSettingsRequest $request, StairStepSettings $stair_step_settings)
    {
        try {

            $stair_step_settings->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('stair_step_setting::stair_step_settings.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('stair_step_setting/stair_step_settings/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('stair_step_setting/stair_step_settings/' . $stair_step_settings->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple stair_step_settings.
     *
     * @param Model   $stair_step_settings
     *
     * @return Response
     */
    public function delete(StairStepSettingsRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('stair_step_setting::stair_step_settings.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('stair_step_setting/stair_step_settings'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/stair_step_setting/stair_step_settings'))
                ->redirect();
        }

    }

    /**
     * Restore deleted stair_step_settings.
     *
     * @param Model   $stair_step_settings
     *
     * @return Response
     */
    public function restore(StairStepSettingsRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('stair_step_setting::stair_step_settings.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/stair_step_setting/stair_step_settings'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/stair_step_setting/stair_step_settings/'))
                ->redirect();
        }

    }

}
