<?php

namespace Litecms\StairStepSetting\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\StairStepSetting\Models\StairStepSettings;

class StairStepSettingsPolicy
{

    /**
     * Determine if the given user can view the stair_step_settings.
     *
     * @param UserPolicy $user
     * @param StairStepSettings $stair_step_settings
     *
     * @return bool
     */
    public function view(UserPolicy $user, StairStepSettings $stair_step_settings)
    {
        if ($user->canDo('stair_step_setting.stair_step_settings.view') && $user->isAdmin()) {
            return true;
        }

        return $stair_step_settings->user_id == user_id() && $stair_step_settings->user_type == user_type();
    }

    /**
     * Determine if the given user can create a stair_step_settings.
     *
     * @param UserPolicy $user
     * @param StairStepSettings $stair_step_settings
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('stair_step_setting.stair_step_settings.create');
    }

    /**
     * Determine if the given user can update the given stair_step_settings.
     *
     * @param UserPolicy $user
     * @param StairStepSettings $stair_step_settings
     *
     * @return bool
     */
    public function update(UserPolicy $user, StairStepSettings $stair_step_settings)
    {
        if ($user->canDo('stair_step_setting.stair_step_settings.edit') && $user->isAdmin()) {
            return true;
        }

        return $stair_step_settings->user_id == user_id() && $stair_step_settings->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given stair_step_settings.
     *
     * @param UserPolicy $user
     * @param StairStepSettings $stair_step_settings
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, StairStepSettings $stair_step_settings)
    {
        return $stair_step_settings->user_id == user_id() && $stair_step_settings->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given stair_step_settings.
     *
     * @param UserPolicy $user
     * @param StairStepSettings $stair_step_settings
     *
     * @return bool
     */
    public function verify(UserPolicy $user, StairStepSettings $stair_step_settings)
    {
        if ($user->canDo('stair_step_setting.stair_step_settings.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given stair_step_settings.
     *
     * @param UserPolicy $user
     * @param StairStepSettings $stair_step_settings
     *
     * @return bool
     */
    public function approve(UserPolicy $user, StairStepSettings $stair_step_settings)
    {
        if ($user->canDo('stair_step_setting.stair_step_settings.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
