<?php

namespace Litecms\StairStepSetting\Providers;

use Illuminate\Support\ServiceProvider;

class StairStepSettingServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'stair_step_setting');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'stair_step_setting');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.stair_step_setting', function ($app) {
            return $this->app->make('Litecms\StairStepSetting\StairStepSetting');
        });

                // Bind StairStepSettings to repository
        $this->app->bind(
            'Litecms\StairStepSetting\Interfaces\StairStepSettingsRepositoryInterface',
            \Litecms\StairStepSetting\Repositories\Eloquent\StairStepSettingsRepository::class
        );

        $this->app->register(\Litecms\StairStepSetting\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\StairStepSetting\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.stair_step_setting'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/stair_step_setting.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/stair_step_setting')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/stair_step_setting')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
